@@ -41,7 +41,10 @@ if len(changed) <= 5:
     for change in changed:
         write("  * %s" % change)
 
+log = log.split("\n")
 while log:
-    write(log[:80])
-    log = log[80:]
+    line = log.pop(0)
+    while line:
+        write(line[:80])
+        line = line[80:]
 # }}}
